job "lldap" {
  schedule = "@daily"

  config {
    repo = "rclone::ftp,env_auth:/nomad/lldap"
    passphrase = env("BACKUP_PASSPHRASE")
  }

  task "Create local backup dir" {
    pre_script {
      on_backup = "mkdir -p /local/lldap"
    }
  }

  task "Backup database" {
    mysql "Backup database" {
      hostname       = env("MYSQL_HOST")
      port           = env("MYSQL_PORT")
      username       = env("MYSQL_USER")
      password       = env("MYSQL_PASSWORD")
      database       = "lldap"
      no_tablespaces = true
      dump_to        = "/local/lldap/dump.sql"
    }
  }

  backup {
    paths = ["/local/lldap"]

    backup_opts {
      Host = "nomad"
    }

    restore_opts {
      Host = ["nomad"]
      # Because path is absolute
      Target = "/"
    }
  }

  forget {
    KeepLast = 2
    KeepDaily = 30
    KeepWeekly = 8
    KeepMonthly = 6
    KeepYearly = 2
    Prune = true
  }
}
